@@ -1,9 +1,11 @@
+# flake8: noqa
 # First import bases
 # Load all base plugins
-from . import parsers, plugins
+from . import parsers
 from .api import api
 from .base import BaseTool, tools, wordlistools
+from .plugins import *
 
 # Init home directory and load all home plugins
 wordlistools.init()
-__all__ = ["parsers", "plugins", "api", "BaseTool", "tools", "wordlistools"]
+__all__ = ["parsers", "api", "BaseTool", "tools", "wordlistools"]
